@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backend.py 10352 2017-10-08 04:46:26Z David $
+# $Id: Backend.py 9594 2016-03-18 12:59:58Z Judy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2017-10-08 12:46:26 +0800 (Sun, 08 Oct 2017) $
-# $Revision: 10352 $
+# $Author: Judy $
+# $Date: 2016-03-18 20:59:58 +0800 (五, 18  3 2016) $
+# $Revision: 9594 $
 
 from urllib import urlopen, urlencode, quote
 from django.core.mail.backends.base import BaseEmailBackend
@@ -30,6 +30,14 @@ class EmailBackend(BaseEmailBackend):
         """
         super(EmailBackend, self).__init__(fail_silently=fail_silently)
 
+        if not username:
+            from django.conf import settings
+            username = settings.EMAIL_HOST_USER 
+            password = settings.EMAIL_HOST_PASSWORD
+            host = settings.EMAIL_HOST
+            use_tls = settings.EMAIL_USE_TLS
+            port = settings.EMAIL_PORT
+
         # username input:
         # admin$templates_shop$templates_shop_mails
         if '$' in username:
@@ -43,6 +51,9 @@ class EmailBackend(BaseEmailBackend):
             
         self.password = password
 
+        if settings.DEFAULT_FROM_EMAIL:
+            self.from_email = settings.DEFAULT_FROM_EMAIL
+
         if host is None:
             host = 'localhost'
 
@@ -110,12 +121,15 @@ class EmailBackend(BaseEmailBackend):
                 app = self.appName
             token = self._getToken(app)
             title = utf8(email.subject)
+
+            fromMail = email.from_email if email.from_email else self.from_email
+
             data = {
                 'token': token,
                 'title': title,
                 'emails': ','.join(email.to),
                 'text': utf8(email.body),
-                'sender': email.from_email,
+                'sender': fromMail,
             }
 
             replyTo = email.extra_headers.get('Reply-To', '')
